# Changelog

## [0.3.4](https://github.com/czimaginginstitute/zarr-particle-tools/compare/zarr-particle-tools-v0.3.3...zarr-particle-tools-v0.3.4) (2025-11-17)


### 🐞 Bug Fixes

* Remove CCPEM-pipeliner extra dependency. ([#16](https://github.com/czimaginginstitute/zarr-particle-tools/issues/16)) ([1ca9f32](https://github.com/czimaginginstitute/zarr-particle-tools/commit/1ca9f3260bc47613caba2f90efb4d64433bccba2))

## [0.3.3](https://github.com/czimaginginstitute/zarr-particle-tools/compare/zarr-particle-tools-v0.3.2...zarr-particle-tools-v0.3.3) (2025-11-17)


### 🧹 Miscellaneous Chores

* Enable publishing workflow for PyPI ([#14](https://github.com/czimaginginstitute/zarr-particle-tools/issues/14)) ([3b1fa32](https://github.com/czimaginginstitute/zarr-particle-tools/commit/3b1fa32e61150e758adc92bd79e6d2966c4546b5))

## [0.3.2](https://github.com/czimaginginstitute/zarr-particle-tools/compare/zarr-particle-tools-v0.3.1...zarr-particle-tools-v0.3.2) (2025-11-17)


### 🧹 Miscellaneous Chores

* Address medium security vulnerabilities. ([#11](https://github.com/czimaginginstitute/zarr-particle-tools/issues/11)) ([bdd500b](https://github.com/czimaginginstitute/zarr-particle-tools/commit/bdd500b5a0ac668169544d8d3dad7fa125af8147))

## [0.3.1](https://github.com/czimaginginstitute/zarr-particle-tools/compare/zarr-particle-tools-v0.3.0...zarr-particle-tools-v0.3.1) (2025-11-17)


### 🐞 Bug Fixes

* add CONTRIBUTING.md ([#8](https://github.com/czimaginginstitute/zarr-particle-tools/issues/8)) ([d1a6a07](https://github.com/czimaginginstitute/zarr-particle-tools/commit/d1a6a071c10ba2a48c973dda187155d6220957f2))
* use caching for pytest only on main ([#7](https://github.com/czimaginginstitute/zarr-particle-tools/issues/7)) ([c2f7f99](https://github.com/czimaginginstitute/zarr-particle-tools/commit/c2f7f99218f145fac2f5ca2e6e3671cf431de506))

## [0.3.0](https://github.com/czimaginginstitute/zarr-particle-tools/compare/zarr-particle-tools-v0.2.0...zarr-particle-tools-v0.3.0) (2025-11-14)


### ✨ Features

* add rich logging, minor README updates, add tests & bugfix extraction from data portal ([#4](https://github.com/czimaginginstitute/zarr-particle-tools/issues/4)) ([b9feb7e](https://github.com/czimaginginstitute/zarr-particle-tools/commit/b9feb7e90464dfb33e09e7650b319ecb849ba624))


### 🐞 Bug Fixes

* pytest caching ([#5](https://github.com/czimaginginstitute/zarr-particle-tools/issues/5)) ([8102fd9](https://github.com/czimaginginstitute/zarr-particle-tools/commit/8102fd9297085fafcfb912f1cba7c44a90ec3f5e))

## [0.2.0](https://github.com/czimaginginstitute/zarr-particle-tools/compare/zarr-particle-tools-v0.1.0...zarr-particle-tools-v0.2.0) (2025-11-14)


### ✨ Features

* setup ci/cd pytest and improve tests ([#2](https://github.com/czimaginginstitute/zarr-particle-tools/issues/2)) ([552c2ad](https://github.com/czimaginginstitute/zarr-particle-tools/commit/552c2ad1a51eed3ba637cd68524c542d00c97b37))


### 🧹 Miscellaneous Chores

* add RP, prep for open source ([#1](https://github.com/czimaginginstitute/zarr-particle-tools/issues/1)) ([add0ae1](https://github.com/czimaginginstitute/zarr-particle-tools/commit/add0ae1ba0ba1ff3b93751b153ae18ec344e492f))
